# GooseSLURM

[![Documentation Status](https://readthedocs.org/projects/gooseslurm/badge/?version=latest)](http://gooseslurm.geus.me/en/latest/?badge=latest)

**Project's website: [gooseslurm.rtfd.io](https://gooseslurm.rtfd.io)**
